README FILE

Datum library
 
Datum is a robot framework library that contains a set of functions for working with JSON files, PDF documents, and text data.
These functions may be useful for a wide range of tasks, such as verifying the integrity of data, performing basic data analysis, extracting data from PDFs, and converting PDFs into other formats.


Installation
pip install robotframework-datum
Running this command installs also the latest version of dependencies.



Keywords
"Compare JSON Files" function likely compares the contents of two JSON files and returns a Boolean value indicating whether or not they are the same. This could be useful for verifying that two JSON files have the same structure and data.

"Compare PDF And Return Differences" function probably compares the contents of two PDF documents and returns a list of any differences that it finds. This could be useful for verifying that two PDF documents are the same, or for identifying any changes that have been made between versions.

"Count Occurrences" function likely counts the number of times a particular string or pattern appears in a given piece of text. This could be useful for performing basic data analysis or for identifying patterns in text data.

"Count PDF Pages" function probably counts the number of pages in a PDF document. This could be useful for determining the length of a document or for verifying that a PDF has been fully generated.

"Decompose PDF" function likely breaks a PDF document down into its individual components, such as text, images, and other media. This could be useful for extracting data from a PDF or for repurposing the content of a PDF in another format.

"PDF To TXT" function probably converts a PDF document into a plain text file. This could be useful for extracting the text content of a PDF for further processing or analysis.

Library website
https://robotframeworkdatum.github.io/
